# Honeydew
This library is a collection of database and GCP connector for ETL

## Installation
```
pip install honeydew
```
<br />

You can find the documentation [here](https://honeydew-lib.github.io/)!
